/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "Attr.h"
#include "CDATASection.h"
#include "CSSRule.h"
#include "CSSStyleDeclaration.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "Comment.h"
#include "DOMSelection.h"
#include "DOMWindow.h"
#include "Document.h"
#include "DocumentFragment.h"
#include "Element.h"
#include "EntityReference.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "NodeFilter.h"
#include "NodeIterator.h"
#include "NodeList.h"
#include "ProcessingInstruction.h"
#include "Range.h"
#include "StyleSheet.h"
#include "Text.h"
#include "TreeWalker.h"
#include "XPathExpression.h"
#include "XPathNSResolver.h"
#include "XPathResult.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomAttr.h"
#include "gdom/GdomCDATASection.h"
#include "gdom/GdomCSSStyleDeclaration.h"
#include "gdom/GdomCanvasRenderingContext2D.h"
#include "gdom/GdomComment.h"
#include "gdom/GdomDOMSelection.h"
#include "gdom/GdomDocument.h"
#include "gdom/GdomDocumentFragment.h"
#include "gdom/GdomElement.h"
#include "gdom/GdomEntityReference.h"
#include "gdom/GdomEvent.h"
#include "gdom/GdomEventTargetNode.h"
#include "gdom/GdomNode.h"
#include "gdom/GdomNodeFilter.h"
#include "gdom/GdomNodeIterator.h"
#include "gdom/GdomNodeList.h"
#include "gdom/GdomProcessingInstruction.h"
#include "gdom/GdomRange.h"
#include "gdom/GdomText.h"
#include "gdom/GdomTreeWalker.h"
#include "gdom/GdomXPathExpression.h"
#include "gdom/GdomXPathNSResolver.h"
#include "gdom/GdomXPathResult.h"
#include "gdom/PrivateGdomAttr.h"
#include "gdom/PrivateGdomCDATASection.h"
#include "gdom/PrivateGdomCSSStyleDeclaration.h"
#include "gdom/PrivateGdomComment.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomDOMSelection.h"
#include "gdom/PrivateGdomDocument.h"
#include "gdom/PrivateGdomDocumentFragment.h"
#include "gdom/PrivateGdomElement.h"
#include "gdom/PrivateGdomEntityReference.h"
#include "gdom/PrivateGdomEvent.h"
#include "gdom/PrivateGdomEventTargetNode.h"
#include "gdom/PrivateGdomNode.h"
#include "gdom/PrivateGdomNodeFilter.h"
#include "gdom/PrivateGdomNodeIterator.h"
#include "gdom/PrivateGdomNodeList.h"
#include "gdom/PrivateGdomProcessingInstruction.h"
#include "gdom/PrivateGdomRange.h"
#include "gdom/PrivateGdomText.h"
#include "gdom/PrivateGdomTreeWalker.h"
#include "gdom/PrivateGdomXPathExpression.h"
#include "gdom/PrivateGdomXPathNSResolver.h"
#include "gdom/PrivateGdomXPathResult.h"
#include "gdom/PrivateIntGdomAttr.h"
#include "gdom/PrivateIntGdomCDATASection.h"
#include "gdom/PrivateIntGdomCSSStyleDeclaration.h"
#include "gdom/PrivateIntGdomComment.h"
#include "gdom/PrivateIntGdomDOMSelection.h"
#include "gdom/PrivateIntGdomDocument.h"
#include "gdom/PrivateIntGdomDocumentFragment.h"
#include "gdom/PrivateIntGdomElement.h"
#include "gdom/PrivateIntGdomEntityReference.h"
#include "gdom/PrivateIntGdomEvent.h"
#include "gdom/PrivateIntGdomNode.h"
#include "gdom/PrivateIntGdomNodeFilter.h"
#include "gdom/PrivateIntGdomNodeIterator.h"
#include "gdom/PrivateIntGdomNodeList.h"
#include "gdom/PrivateIntGdomProcessingInstruction.h"
#include "gdom/PrivateIntGdomRange.h"
#include "gdom/PrivateIntGdomText.h"
#include "gdom/PrivateIntGdomTreeWalker.h"
#include "gdom/PrivateIntGdomXPathExpression.h"
#include "gdom/PrivateIntGdomXPathNSResolver.h"
#include "gdom/PrivateIntGdomXPathResult.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMDocument::GDOMDocument(PassRefPtr<WebCore::Document> impl)
    : GDOMEventTargetNode(impl)
{
}

GDOMDocument::~GDOMDocument()
{
    WebCore::GDOMScriptInterpreter::forgetDOMObject(static_cast<WebCore::Document*>(impl()));
}

GdomElement *
gdom_document_create_element (GdomDocument *thiz, gchar * tag_name)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (tag_name, 0);
    WebCore::String _g_tag_name = WebCore::String::fromUTF8(tag_name);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Element> g_res = WTF::getPtr(item->createElement(_g_tag_name, ec));
    GdomElement * res = static_cast<GdomElement *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomDocumentFragment *
gdom_document_create_document_fragment (GdomDocument *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::DocumentFragment> g_res = WTF::getPtr(item->createDocumentFragment());
    GdomDocumentFragment * res = static_cast<GdomDocumentFragment *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomText *
gdom_document_create_text_node (GdomDocument *thiz, gchar * data)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (data, 0);
    WebCore::String _g_data = WebCore::String::fromUTF8(data);
    PassRefPtr<WebCore::Text> g_res = WTF::getPtr(item->createTextNode(_g_data));
    GdomText * res = static_cast<GdomText *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomComment *
gdom_document_create_comment (GdomDocument *thiz, gchar * data)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (data, 0);
    WebCore::String _g_data = WebCore::String::fromUTF8(data);
    PassRefPtr<WebCore::Comment> g_res = WTF::getPtr(item->createComment(_g_data));
    GdomComment * res = static_cast<GdomComment *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomCDATASection *
gdom_document_create_cdata_section (GdomDocument *thiz, gchar * data)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (data, 0);
    WebCore::String _g_data = WebCore::String::fromUTF8(data);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::CDATASection> g_res = WTF::getPtr(item->createCDATASection(_g_data, ec));
    GdomCDATASection * res = static_cast<GdomCDATASection *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomProcessingInstruction *
gdom_document_create_processing_instruction (GdomDocument *thiz, gchar * target, gchar * data)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (target, 0);
    g_return_val_if_fail (data, 0);
    WebCore::String _g_target = WebCore::String::fromUTF8(target);
    WebCore::String _g_data = WebCore::String::fromUTF8(data);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::ProcessingInstruction> g_res = WTF::getPtr(item->createProcessingInstruction(_g_target, _g_data, ec));
    GdomProcessingInstruction * res = static_cast<GdomProcessingInstruction *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomAttr *
gdom_document_create_attribute (GdomDocument *thiz, gchar * name)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (name, 0);
    WebCore::String _g_name = WebCore::String::fromUTF8(name);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Attr> g_res = WTF::getPtr(item->createAttribute(_g_name, ec));
    GdomAttr * res = static_cast<GdomAttr *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomEntityReference *
gdom_document_create_entity_reference (GdomDocument *thiz, gchar * name)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (name, 0);
    WebCore::String _g_name = WebCore::String::fromUTF8(name);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::EntityReference> g_res = WTF::getPtr(item->createEntityReference(_g_name, ec));
    GdomEntityReference * res = static_cast<GdomEntityReference *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomNodeList *
gdom_document_get_elements_by_tag_name (GdomDocument *thiz, gchar * tagname)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (tagname, 0);
    WebCore::String _g_tagname = WebCore::String::fromUTF8(tagname);
    PassRefPtr<WebCore::NodeList> g_res = WTF::getPtr(item->getElementsByTagName(_g_tagname));
    GdomNodeList * res = static_cast<GdomNodeList *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomNode *
gdom_document_import_node (GdomDocument *thiz, GdomNode * imported_node, gboolean deep)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (imported_node, 0);
    WebCore::Node * _g_imported_node = (gdom_node_get_private(imported_node));
    g_return_val_if_fail (_g_imported_node, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Node> g_res = WTF::getPtr(item->importNode(_g_imported_node, deep, ec));
    GdomNode * res = static_cast<GdomNode *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomElement *
gdom_document_create_element_ns (GdomDocument *thiz, gchar * namespace_uri, gchar * qualified_name)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (namespace_uri, 0);
    g_return_val_if_fail (qualified_name, 0);
    WebCore::String _g_namespace_uri = WebCore::String::fromUTF8(namespace_uri);
    WebCore::String _g_qualified_name = WebCore::String::fromUTF8(qualified_name);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Element> g_res = WTF::getPtr(item->createElementNS(_g_namespace_uri, _g_qualified_name, ec));
    GdomElement * res = static_cast<GdomElement *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomAttr *
gdom_document_create_attribute_ns (GdomDocument *thiz, gchar * namespace_uri, gchar * qualified_name)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (namespace_uri, 0);
    g_return_val_if_fail (qualified_name, 0);
    WebCore::String _g_namespace_uri = WebCore::String::fromUTF8(namespace_uri);
    WebCore::String _g_qualified_name = WebCore::String::fromUTF8(qualified_name);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Attr> g_res = WTF::getPtr(item->createAttributeNS(_g_namespace_uri, _g_qualified_name, ec));
    GdomAttr * res = static_cast<GdomAttr *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomNodeList *
gdom_document_get_elements_by_tag_name_ns (GdomDocument *thiz, gchar * namespace_uri, gchar * local_name)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (namespace_uri, 0);
    g_return_val_if_fail (local_name, 0);
    WebCore::String _g_namespace_uri = WebCore::String::fromUTF8(namespace_uri);
    WebCore::String _g_local_name = WebCore::String::fromUTF8(local_name);
    PassRefPtr<WebCore::NodeList> g_res = WTF::getPtr(item->getElementsByTagNameNS(_g_namespace_uri, _g_local_name));
    GdomNodeList * res = static_cast<GdomNodeList *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomElement *
gdom_document_get_element_by_id (GdomDocument *thiz, gchar * element_id)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (element_id, 0);
    WebCore::String _g_element_id = WebCore::String::fromUTF8(element_id);
    PassRefPtr<WebCore::Element> g_res = WTF::getPtr(item->getElementById(_g_element_id));
    GdomElement * res = static_cast<GdomElement *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomNode *
gdom_document_adopt_node (GdomDocument *thiz, GdomNode * source)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (source, 0);
    WebCore::Node * _g_source = (gdom_node_get_private(source));
    g_return_val_if_fail (_g_source, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Node> g_res = WTF::getPtr(item->adoptNode(_g_source, ec));
    GdomNode * res = static_cast<GdomNode *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomEvent *
gdom_document_create_event (GdomDocument *thiz, gchar * event_type)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (event_type, 0);
    WebCore::String _g_event_type = WebCore::String::fromUTF8(event_type);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::Event> g_res = WTF::getPtr(item->createEvent(_g_event_type, ec));
    GdomEvent * res = static_cast<GdomEvent *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomRange *
gdom_document_create_range (GdomDocument *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::Range> g_res = WTF::getPtr(item->createRange());
    GdomRange * res = static_cast<GdomRange *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomNodeIterator *
gdom_document_create_node_iterator (GdomDocument *thiz, GdomNode * root, gulong what_to_show, GdomNodeFilter * filter, gboolean entity_reference_expansion)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (root, 0);
    g_return_val_if_fail (filter, 0);
    WebCore::Node * _g_root = (gdom_node_get_private(root));
    g_return_val_if_fail (_g_root, 0);
    WebCore::NodeFilter * _g_filter = (gdom_node_filter_get_private(filter));
    g_return_val_if_fail (_g_filter, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::NodeIterator> g_res = WTF::getPtr(item->createNodeIterator(_g_root, what_to_show, _g_filter, entity_reference_expansion, ec));
    GdomNodeIterator * res = static_cast<GdomNodeIterator *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomTreeWalker *
gdom_document_create_tree_walker (GdomDocument *thiz, GdomNode * root, gulong what_to_show, GdomNodeFilter * filter, gboolean entity_reference_expansion)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (root, 0);
    g_return_val_if_fail (filter, 0);
    WebCore::Node * _g_root = (gdom_node_get_private(root));
    g_return_val_if_fail (_g_root, 0);
    WebCore::NodeFilter * _g_filter = (gdom_node_filter_get_private(filter));
    g_return_val_if_fail (_g_filter, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::TreeWalker> g_res = WTF::getPtr(item->createTreeWalker(_g_root, what_to_show, _g_filter, entity_reference_expansion, ec));
    GdomTreeWalker * res = static_cast<GdomTreeWalker *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomCSSStyleDeclaration *
gdom_document_get_override_style (GdomDocument *thiz, GdomElement * element, gchar * pseudo_element)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (element, 0);
    g_return_val_if_fail (pseudo_element, 0);
    WebCore::Element * _g_element = (gdom_element_get_private(element));
    g_return_val_if_fail (_g_element, 0);
    WebCore::String _g_pseudo_element = WebCore::String::fromUTF8(pseudo_element);
    PassRefPtr<WebCore::CSSStyleDeclaration> g_res = WTF::getPtr(item->getOverrideStyle(_g_element, _g_pseudo_element));
    GdomCSSStyleDeclaration * res = static_cast<GdomCSSStyleDeclaration *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomXPathExpression *
gdom_document_create_expression (GdomDocument *thiz, gchar * expression, GdomXPathNSResolver * resolver)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (expression, 0);
    g_return_val_if_fail (resolver, 0);
    WebCore::String _g_expression = WebCore::String::fromUTF8(expression);
    WebCore::XPathNSResolver * _g_resolver = (gdom_x_path_ns_resolver_get_private(resolver));
    g_return_val_if_fail (_g_resolver, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::XPathExpression> g_res = WTF::getPtr(item->createExpression(_g_expression, _g_resolver, ec));
    GdomXPathExpression * res = static_cast<GdomXPathExpression *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomXPathNSResolver *
gdom_document_create_ns_resolver (GdomDocument *thiz, GdomNode * node_resolver)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (node_resolver, 0);
    WebCore::Node * _g_node_resolver = (gdom_node_get_private(node_resolver));
    g_return_val_if_fail (_g_node_resolver, 0);
    PassRefPtr<WebCore::XPathNSResolver> g_res = WTF::getPtr(item->createNSResolver(_g_node_resolver));
    GdomXPathNSResolver * res = static_cast<GdomXPathNSResolver *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomXPathResult *
gdom_document_evaluate (GdomDocument *thiz, gchar * expression, GdomNode * context_node, GdomXPathNSResolver * resolver, gushort type, GdomXPathResult * in_result)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (expression, 0);
    g_return_val_if_fail (context_node, 0);
    g_return_val_if_fail (resolver, 0);
    g_return_val_if_fail (in_result, 0);
    WebCore::String _g_expression = WebCore::String::fromUTF8(expression);
    WebCore::Node * _g_context_node = (gdom_node_get_private(context_node));
    g_return_val_if_fail (_g_context_node, 0);
    WebCore::XPathNSResolver * _g_resolver = (gdom_x_path_ns_resolver_get_private(resolver));
    g_return_val_if_fail (_g_resolver, 0);
    WebCore::XPathResult * _g_in_result = (gdom_x_path_result_get_private(in_result));
    g_return_val_if_fail (_g_in_result, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::XPathResult> g_res = WTF::getPtr(item->evaluate(_g_expression, _g_context_node, _g_resolver, type, _g_in_result, ec));
    GdomXPathResult * res = static_cast<GdomXPathResult *>(WebCore::toGDOM(g_res.get()));
    return res;

}

gboolean
gdom_document_exec_command (GdomDocument *thiz, gchar * command, gboolean user_interface, gchar * value)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (command, 0);
    g_return_val_if_fail (value, 0);
    WebCore::String _g_command = WebCore::String::fromUTF8(command);
    WebCore::String _g_value = WebCore::String::fromUTF8(value);
    gboolean res = item->execCommand(_g_command, user_interface, _g_value);
    return res;

}

gboolean
gdom_document_query_command_enabled (GdomDocument *thiz, gchar * command)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (command, 0);
    WebCore::String _g_command = WebCore::String::fromUTF8(command);
    gboolean res = item->queryCommandEnabled(_g_command);
    return res;

}

gboolean
gdom_document_query_command_indeterm (GdomDocument *thiz, gchar * command)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (command, 0);
    WebCore::String _g_command = WebCore::String::fromUTF8(command);
    gboolean res = item->queryCommandIndeterm(_g_command);
    return res;

}

gboolean
gdom_document_query_command_state (GdomDocument *thiz, gchar * command)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (command, 0);
    WebCore::String _g_command = WebCore::String::fromUTF8(command);
    gboolean res = item->queryCommandState(_g_command);
    return res;

}

gboolean
gdom_document_query_command_supported (GdomDocument *thiz, gchar * command)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (command, 0);
    WebCore::String _g_command = WebCore::String::fromUTF8(command);
    gboolean res = item->queryCommandSupported(_g_command);
    return res;

}

gchar *
gdom_document_query_command_value (GdomDocument *thiz, gchar * command)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (command, 0);
    WebCore::String _g_command = WebCore::String::fromUTF8(command);
    gchar * res = _G_GET_UTF8(item->queryCommandValue(_g_command));
    return res;

}

GdomNodeList *
gdom_document_get_elements_by_name (GdomDocument *thiz, gchar * element_name)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (element_name, 0);
    WebCore::String _g_element_name = WebCore::String::fromUTF8(element_name);
    PassRefPtr<WebCore::NodeList> g_res = WTF::getPtr(item->getElementsByName(_g_element_name));
    GdomNodeList * res = static_cast<GdomNodeList *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomElement *
gdom_document_element_from_point (GdomDocument *thiz, glong x, glong y)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::Element> g_res = WTF::getPtr(item->elementFromPoint(x, y));
    GdomElement * res = static_cast<GdomElement *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomDOMSelection *
gdom_document_get_selection (GdomDocument *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::DOMSelection> g_res = WTF::getPtr(item->getSelection());
    GdomDOMSelection * res = static_cast<GdomDOMSelection *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomCSSStyleDeclaration *
gdom_document_create_css_style_declaration (GdomDocument *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::CSSStyleDeclaration> g_res = WTF::getPtr(item->createCSSStyleDeclaration());
    GdomCSSStyleDeclaration * res = static_cast<GdomCSSStyleDeclaration *>(WebCore::toGDOM(g_res.get()));
    return res;

}

GdomNodeList *
gdom_document_get_elements_by_class_name (GdomDocument *thiz, gchar * tagname)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::Document * item = (gdom_document_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (tagname, 0);
    WebCore::String _g_tagname = WebCore::String::fromUTF8(tagname);
    PassRefPtr<WebCore::NodeList> g_res = WTF::getPtr(item->getElementsByClassName(_g_tagname));
    GdomNodeList * res = static_cast<GdomNodeList *>(WebCore::toGDOM(g_res.get()));
    return res;

}


/* XXX TODO: custom function gdom_document_query_selector */


/* XXX TODO: custom function gdom_document_query_selector_all */

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "Document.h"
#include <gdom/GdomDocument.h>
#include <gdom/PrivateGdomDocument.h>
#include <gdom/PrivateIntGdomDocument.h>
#include <gdom/GdomDocumentprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomDocument, gdom_document, GDOM_TYPE_EVENT_TARGET_NODE);

/*
struct _GdomDocumentPrivate {
    class WebCore::Document *item;
};

#define GDOM_DOCUMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_DOCUMENT, GdomDocumentPrivate))
*/
G_END_DECLS
WebCore::Document *
gdom_document_get_private(GdomDocument *request)
{
    GDOMDocument *res;
    res = static_cast<GDOMDocument*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::Document*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_DOCTYPE,
    PROP_IMPLEMENTATION,
    PROP_DOCUMENT_ELEMENT,
    PROP_INPUT_ENCODING,
    PROP_XML_ENCODING,
    PROP_XML_VERSION,
    PROP_XML_STANDALONE,
    PROP_DOCUMENT_URI,
    PROP_DEFAULT_VIEW,
    PROP_STYLE_SHEETS,
    PROP_TITLE,
    PROP_REFERRER,
    PROP_DOMAIN,
    PROP_URL,
    PROP_COOKIE,
    PROP_BODY,
    PROP_IMAGES,
    PROP_APPLETS,
    PROP_LINKS,
    PROP_FORMS,
    PROP_ANCHORS,
    PROP_LAST_MODIFIED,
    PROP_LOCATION,
    PROP_CHARSET,
    PROP_DEFAULT_CHARSET,
    PROP_READY_STATE,
    PROP_CHARACTER_SET,
    PROP_PREFERRED_STYLESHEET_SET,
    PROP_SELECTED_STYLESHEET_SET,
};


static void gdom_document_finalize(GObject* object)
{
    /*GdomDocument* request = GDOM_DOCUMENT(object);*/
    /*GdomDocumentPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_EVENT_TARGET_NODE));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_document_parent_class)->finalize(object);
}

static void gdom_document__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomDocument *self = GDOM_DOCUMENT(object);
    WebCore::Document * gself = (gdom_document_get_private(self));
    switch (prop_id) {
     case PROP_XML_VERSION:
    {
         WebCore::ExceptionCode ec = 0;
         gself->setXMLVersion(WebCore::String::fromUTF8(g_value_get_string (value)) , ec );
         break;
    }
     case PROP_XML_STANDALONE:
    {
         WebCore::ExceptionCode ec = 0;
         gself->setXMLStandalone((g_value_get_boolean (value)) , ec );
         break;
    }
     case PROP_DOCUMENT_URI:
    {
         gself->setDocumentURI(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TITLE:
    {
         gself->setTitle(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_DOMAIN:
    {
         gself->setDomain(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_COOKIE:
    {
         gself->setCookie(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CHARSET:
    {
         gself->setCharset(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_SELECTED_STYLESHEET_SET:
    {
         gself->setSelectedStylesheetSet(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_document__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomDocument *self = GDOM_DOCUMENT(object);
    WebCore::Document * gself = (gdom_document_get_private(self));
    switch (prop_id) {
    case PROP_DOCTYPE:
    {
         PassRefPtr<WebCore::DocumentType> ptr = gself->doctype();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_IMPLEMENTATION:
    {
         PassRefPtr<WebCore::DOMImplementation> ptr = gself->implementation();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_DOCUMENT_ELEMENT:
    {
         PassRefPtr<WebCore::Element> ptr = gself->documentElement();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_INPUT_ENCODING:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->inputEncoding()));
         break;
    }
    case PROP_XML_ENCODING:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->xmlEncoding()));
         break;
    }
    case PROP_XML_VERSION:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->xmlVersion()));
         break;
    }
    case PROP_XML_STANDALONE:
    {
         g_value_set_boolean (value, gself->xmlStandalone());
         break;
    }
    case PROP_DOCUMENT_URI:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->documentURI()));
         break;
    }
    case PROP_DEFAULT_VIEW:
    {
         PassRefPtr<WebCore::DOMWindow> ptr = gself->defaultView();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_STYLE_SHEETS:
    {
         PassRefPtr<WebCore::StyleSheetList> ptr = gself->styleSheets();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_TITLE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->title()));
         break;
    }
    case PROP_REFERRER:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->referrer()));
         break;
    }
    case PROP_DOMAIN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->domain()));
         break;
    }
    case PROP_URL:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->url()));
         break;
    }
    case PROP_COOKIE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->cookie()));
         break;
    }
    case PROP_BODY:
    {
         PassRefPtr<WebCore::HTMLElement> ptr = gself->body();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_IMAGES:
    {
         PassRefPtr<WebCore::HTMLCollection> ptr = gself->images();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_APPLETS:
    {
         PassRefPtr<WebCore::HTMLCollection> ptr = gself->applets();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_LINKS:
    {
         PassRefPtr<WebCore::HTMLCollection> ptr = gself->links();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_FORMS:
    {
         PassRefPtr<WebCore::HTMLCollection> ptr = gself->forms();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_ANCHORS:
    {
         PassRefPtr<WebCore::HTMLCollection> ptr = gself->anchors();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_LAST_MODIFIED:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->lastModified()));
         break;
    }
    case PROP_CHARSET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->charset()));
         break;
    }
    case PROP_DEFAULT_CHARSET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->defaultCharset()));
         break;
    }
    case PROP_READY_STATE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->readyState()));
         break;
    }
    case PROP_CHARACTER_SET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->characterSet()));
         break;
    }
    case PROP_PREFERRED_STYLESHEET_SET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->preferredStylesheetSet()));
         break;
    }
    case PROP_SELECTED_STYLESHEET_SET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->selectedStylesheetSet()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_document_class_init(GdomDocumentClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_document_finalize;
    g_klass->set_property = gdom_document__set_property_fn;
    g_klass->get_property = gdom_document__get_property_fn;

    g_object_class_install_property (g_klass, PROP_DOCTYPE,
            g_param_spec_object ("doctype", /* name */
                "document_doctype", /* short description */
                "read-only  GdomDocumentType * Document.doctype", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOCUMENT_TYPE, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_IMPLEMENTATION,
            g_param_spec_object ("implementation", /* name */
                "document_implementation", /* short description */
                "read-only  GdomDOMImplementation * Document.implementation", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOM_IMPLEMENTATION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_DOCUMENT_ELEMENT,
            g_param_spec_object ("document_element", /* name */
                "document_document_element", /* short description */
                "read-only  GdomElement * Document.document_element", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_ELEMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_INPUT_ENCODING,
            g_param_spec_string ("input_encoding", /* name */
                "document_input_encoding", /* short description */
                "read-only  gchar * Document.input_encoding", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_XML_ENCODING,
            g_param_spec_string ("xml_encoding", /* name */
                "document_xml_encoding", /* short description */
                "read-only  gchar * Document.xml_encoding", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_XML_VERSION,
            g_param_spec_string ("xml_version", /* name */
                "document_xml_version", /* short description */
                "read-write  gchar * Document.xml_version", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_XML_STANDALONE,
            g_param_spec_boolean ("xml_standalone", /* name */
                "document_xml_standalone", /* short description */
                "read-write  gboolean Document.xml_standalone", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DOCUMENT_URI,
            g_param_spec_string ("document_uri", /* name */
                "document_document_uri", /* short description */
                "read-write  gchar * Document.document_uri", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DEFAULT_VIEW,
            g_param_spec_object ("default_view", /* name */
                "document_default_view", /* short description */
                "read-only  GdomDOMWindow * Document.default_view", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOM_WINDOW, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_STYLE_SHEETS,
            g_param_spec_object ("style_sheets", /* name */
                "document_style_sheets", /* short description */
                "read-only  GdomStyleSheetList * Document.style_sheets", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_STYLE_SHEET_LIST, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_TITLE,
            g_param_spec_string ("title", /* name */
                "document_title", /* short description */
                "read-write  gchar * Document.title", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_REFERRER,
            g_param_spec_string ("referrer", /* name */
                "document_referrer", /* short description */
                "read-only  gchar * Document.referrer", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_DOMAIN,
            g_param_spec_string ("domain", /* name */
                "document_domain", /* short description */
                "read-write  gchar * Document.domain", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_URL,
            g_param_spec_string ("url", /* name */
                "document_url", /* short description */
                "read-only  gchar * Document.url", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_COOKIE,
            g_param_spec_string ("cookie", /* name */
                "document_cookie", /* short description */
                "read-write  gchar * Document.cookie", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_BODY,
            g_param_spec_object ("body", /* name */
                "document_body", /* short description */
                "read-write  GdomHTMLElement * Document.body", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_ELEMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_IMAGES,
            g_param_spec_object ("images", /* name */
                "document_images", /* short description */
                "read-only  GdomHTMLCollection * Document.images", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_COLLECTION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_APPLETS,
            g_param_spec_object ("applets", /* name */
                "document_applets", /* short description */
                "read-only  GdomHTMLCollection * Document.applets", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_COLLECTION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_LINKS,
            g_param_spec_object ("links", /* name */
                "document_links", /* short description */
                "read-only  GdomHTMLCollection * Document.links", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_COLLECTION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_FORMS,
            g_param_spec_object ("forms", /* name */
                "document_forms", /* short description */
                "read-only  GdomHTMLCollection * Document.forms", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_COLLECTION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ANCHORS,
            g_param_spec_object ("anchors", /* name */
                "document_anchors", /* short description */
                "read-only  GdomHTMLCollection * Document.anchors", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_COLLECTION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_LAST_MODIFIED,
            g_param_spec_string ("last_modified", /* name */
                "document_last_modified", /* short description */
                "read-only  gchar * Document.last_modified", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_CHARSET,
            g_param_spec_string ("charset", /* name */
                "document_charset", /* short description */
                "read-write  gchar * Document.charset", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DEFAULT_CHARSET,
            g_param_spec_string ("default_charset", /* name */
                "document_default_charset", /* short description */
                "read-only  gchar * Document.default_charset", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_READY_STATE,
            g_param_spec_string ("ready_state", /* name */
                "document_ready_state", /* short description */
                "read-only  gchar * Document.ready_state", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_CHARACTER_SET,
            g_param_spec_string ("character_set", /* name */
                "document_character_set", /* short description */
                "read-only  gchar * Document.character_set", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_PREFERRED_STYLESHEET_SET,
            g_param_spec_string ("preferred_stylesheet_set", /* name */
                "document_preferred_stylesheet_set", /* short description */
                "read-only  gchar * Document.preferred_stylesheet_set", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SELECTED_STYLESHEET_SET,
            g_param_spec_string ("selected_stylesheet_set", /* name */
                "document_selected_stylesheet_set", /* short description */
                "read-write  gchar * Document.selected_stylesheet_set", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomDocumentPrivate));*/
}

static void gdom_document_init(GdomDocument* request)
{
    /*GdomDocumentPrivate* priv = GDOM_DOCUMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

